﻿using System;
using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;

namespace DisplayASimpleMap.Controllers
{
    public class DisplayASimpleMapController : Controller
    {
        public ActionResult DisplayASimpleMap()
        {
            Map map = new Map("Map1",
                 new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage),
                 new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage));

            map.MapUnit = GeographyUnit.DecimalDegree;
            map.CurrentExtent = new RectangleShape(-125, 72, 50, -46);

            map.MapBackground = new BackgroundLayer(new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF")));
            map.CustomOverlays.Add(new WorldMapKitWmsWebOverlay());

            return View(map);
        }

        [MapActionFilter]
        public string ClickEvent(Map map, GeoCollection<object> args)
        {
            // Argument reference:
            // 0: World longitude coordinate (x)
            // 1: World latitude coordinate (y)
            // 2: Current scale of the map

            string popupJson = string.Empty;
            PointShape position = new PointShape(Convert.ToDouble(args[0]), Convert.ToDouble(args[1]));

            // Create a new CloudPopup and set some common properties
            CloudPopup infoPopup = new CloudPopup("ParcelInfoPopup");
            infoPopup.HasCloseButton = true;

            infoPopup.AutoPan = true;
            infoPopup.AutoSize = true;


            // Create a default instructional popup
            infoPopup.ContentHtml = "<div class=\\\"normalBlueTx\\\">Please click on a Parcel to show its information.div>";
            infoPopup.Position = position;

            // Clear the map's Popups collection and add our new one
            map.Popups.Clear();
            map.Popups.Add(infoPopup);

            // Convert the popup to JSON and return it to the client
            popupJson = infoPopup.ToJson();

            return popupJson;
        }
    }
}